REM The following accounts are needed for proper MOSS 2007 installation.
REM Change the value of set myDC and myDcExt to your domain name and extension.
REM This script will create an OU called Service Accounts, where accounts will be added.
REM As a Best Practice, never create accounts in the default "Users" container.
REM Don't use accounts longer than 20 chars because of Pre-Windows 2000 login limitation.
REM Script written by Zubair Alexander on 12/31/09.

set myPassword=password
set myDC=SeattlePro1
set myDcExt=com

REM The following will create an OU called Service Accounts.
dsadd OU "ou=Service Accounts,dc=%myDC%,dc=%myDcExt%"

REM Now create all the service accounts.
dsadd user cn="SP_Install,ou=Service Accounts,dc=%myDC%,dc=%myDcExt%" -desc "Temporary MOSS installation account. This account is only used temporarily to install MOSS. Must be a member of Domain Users, Domain Admins (suggested), Local Administrator on each front-end server, Remote Desktop Users (suggested)." -mustchpwd no -pwdneverexpires yes -canchpwd no -pwd %myPassword% -disabled no

dsadd user cn="SP_CaAppPool,ou=Service Accounts,dc=%myDC%,dc=%myDcExt%" -desc "MOSS Central Administration Application Pool account. This account is used to run the CA Site Application Pool (in IIS). Must be a member of Domain Users, IIS_WPG, WSS_WPG and WSSAdmin_WPG groups." -mustchpwd no -pwdneverexpires yes -canchpwd no -pwd %myPassword% -disabled no

dsadd user cn="SP_Admin,ou=Service Accounts,dc=%myDC%,dc=%myDcExt%" -desc "MOSS Master Administrator account. Must be a member of Domain Users, IIS_WPG, WSS_WPG, and WSSAdmin_WPG, Domain Admins (suggested), Remote Desktop Users (suggested), VSDevelopers (for Development Systems only)." -mustchpwd no -pwdneverexpires yes -canchpwd no -pwd %myPassword% -disabled no

dsadd user cn="SP_AppPool,ou=Service Accounts,dc=%myDC%,dc=%myDcExt%" -desc "MOSS Application Pool account. This account is used to run the Site Application Pools (in IIS). Must be a member of Domain Users, IIS_WPG, WSS_WPG, and WSSAdmin_WPG groups." -mustchpwd no -pwdneverexpires yes -canchpwd no -pwd %myPassword% -disabled no

dsadd user cn="SP_Services,ou=Service Accounts,dc=%myDC%,dc=%myDcExt%" -desc "MOSS & SQL Services account. This account is used to run the MOSS and SQL services (NOT Search service). Must be a member of Domain Users, Domain Admins (suggested), Local Administrator on each front-end server, IIS_WPG, WSS_WPG, and WSSAdmin_WPG groups." -mustchpwd no -pwdneverexpires yes -canchpwd no -pwd %myPassword% -disabled no

dsadd user cn="SP_Search,ou=Service Accounts,dc=%myDC%,dc=%myDcExt%" -desc "MOSS Search Service account. Must be a member of Domain Users, Local Administrator on each front-end server, IIS_WPG, WSS_WPG, and WSSAdmin_WPG groups. This service is used by every SSP in the server farm and is used to write content index files to the index location on index servers and to propagate the searchable index to all query servers in a MOSS farm." -mustchpwd no -pwdneverexpires yes -canchpwd no -pwd %myPassword% -disabled no

dsadd user cn="SP_ContentAccess,ou=Service Accounts,dc=%myDC%,dc=%myDcExt%" -desc "MOSS Content Access account. Must be a member of Domain Users group. This account is used by an SSP to access content sources unless a specific alternative content access account is specified in a crawl rule. Each SSP includes a default content access account." -mustchpwd no -pwdneverexpires yes -canchpwd no -pwd %myPassword% -disabled no
